@@ -14,6 +14,7 @@
 # under the License.
 import jinja2
 import mock
+import yaml
 
 from swiftclient import exceptions as swiftexceptions
 
@@ -82,7 +83,13 @@ ROLE_DATA_DISABLE_CONSTRAINTS_YAML = r"""
   disable_constraints: True
 """
 
-JINJA_SNIPPET_DISABLE_CONSTRAINTS = r"""
+ROLE_DATA_ENABLE_NETWORKS = r"""
+- name: RoleWithNetworks
+  networks:
+    - anetwork
+"""
+
+JINJA_SNIPPET_DISABLE_CONSTRAINTS_OLD = r"""
   {{role}}Image:
     type: string
     default: overcloud-full
@@ -92,12 +99,36 @@ JINJA_SNIPPET_DISABLE_CONSTRAINTS = r"""
 {% endif %}
 """
 
+JINJA_SNIPPET_DISABLE_CONSTRAINTS = r"""
+  {{role.name}}Image:
+    type: string
+    default: overcloud-full
+{% if role.disable_constraints is not defined %}
+    constraints:
+      - custom_constraint: glance.image
+{% endif %}
+"""
+
 EXPECTED_JINJA_RESULT_DISABLE_CONSTRAINTS = r"""
   RoleWithDisableConstraintsImage:
     type: string
     default: overcloud-full
 """
 
+JINJA_SNIPPET_ROLE_NETWORKS = r"""
+{%- for network in networks %}
+    {%- if network.name in role.networks%}
+  {{network.name}}Port:
+    type: {{role.name}}::{{network.name}}::Port
+    {%- endif %}
+{% endfor %}
+"""
+
+EXPECTED_JINJA_RESULT_ROLE_NETWORKS = r"""
+  anetworkPort:
+    type: RoleWithNetworks::anetwork::Port
+"""
+
 
 class UploadTemplatesActionTest(base.TestCase):
 
@@ -188,28 +219,23 @@ class ProcessTemplatesActionTest(base.TestCase):
     @mock.patch('heatclient.common.template_utils.'
                 'process_multiple_environments_and_files')
     @mock.patch('heatclient.common.template_utils.get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     def test_run(self, mock_get_object_client,
-                 mock_get_workflow_client, mock_get_template_contents,
+                 mock_get_template_contents,
                  mock_process_multiple_environments_and_files):
 
         mock_ctx = mock.MagicMock()
         swift = mock.MagicMock(url="http://test.com")
-        swift.get_object.side_effect = swiftexceptions.ClientException(
-            'atest2')
-        mock_get_object_client.return_value = swift
-
-        mock_mistral = mock.MagicMock()
-        mock_env = mock.MagicMock()
-        mock_env.variables = {
+        mock_env = yaml.safe_dump({
             'temp_environment': 'temp_environment',
             'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}],
-        }
-        mock_mistral.environments.get.return_value = mock_env
-        mock_get_workflow_client.return_value = mock_mistral
+            'environments': [{u'path': u'environments/test.yaml'}]
+        }, default_flow_style=False)
+        swift.get_object.side_effect = (
+            ({}, mock_env),
+            swiftexceptions.ClientException('atest2')
+        )
+        mock_get_object_client.return_value = swift
 
         mock_get_template_contents.return_value = ({}, {
             'heat_template_version': '2016-04-30'
@@ -230,38 +256,44 @@ class ProcessTemplatesActionTest(base.TestCase):
             }
         })
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_process_custom_roles(self, get_obj_client_mock):
+    def _custom_roles_mock_objclient(self, snippet_name, snippet_content,
+                                     role_data=None):
 
         def return_multiple_files(*args):
             if args[1] == constants.OVERCLOUD_J2_NAME:
                 return ['', JINJA_SNIPPET]
-            if args[1] == 'foo.j2.yaml':
-                return ['', JINJA_SNIPPET]
+            if args[1] == snippet_name:
+                return ['', snippet_content]
             if args[1] == constants.OVERCLOUD_J2_EXCLUDES:
                 return ['', J2_EXCLUDES]
             elif args[1] == constants.OVERCLOUD_J2_ROLES_NAME:
-                return ['', ROLE_DATA_YAML]
+                return ['', role_data or ROLE_DATA_YAML]
             elif args[1] == constants.OVERCLOUD_J2_NETWORKS_NAME:
                 return ['', NETWORK_DATA_YAML]
 
         def return_container_files(*args):
             return ('headers', [
                 {'name': constants.OVERCLOUD_J2_NAME},
-                {'name': 'foo.j2.yaml'},
+                {'name': snippet_name},
                 {'name': constants.OVERCLOUD_J2_ROLES_NAME},
                 {'name': constants.OVERCLOUD_J2_NETWORKS_NAME}])
 
-        mock_ctx = mock.MagicMock()
         # setup swift
         swift = mock.MagicMock()
         swift.get_object = mock.MagicMock(side_effect=return_multiple_files)
         swift.get_container = mock.MagicMock(
             side_effect=return_container_files)
+        return swift
+
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_process_custom_roles(self, get_obj_client_mock):
+        swift = self._custom_roles_mock_objclient(
+            'foo.j2.yaml', JINJA_SNIPPET)
         get_obj_client_mock.return_value = swift
 
         # Test
         action = templates.ProcessTemplatesAction()
+        mock_ctx = mock.MagicMock()
         action._process_custom_roles(mock_ctx)
 
         get_object_mock_calls = [
@@ -284,47 +316,70 @@ class ProcessTemplatesActionTest(base.TestCase):
             put_object_mock_calls, any_order=True)
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_process_custom_roles_disable_constraints(
-            self, get_obj_client_mock):
-
-        def return_multiple_files(*args):
-            if args[1] == constants.OVERCLOUD_J2_NAME:
-                return ['', JINJA_SNIPPET_DISABLE_CONSTRAINTS]
-            if args[1] == 'disable-constraints.role.j2.yaml':
-                return ['', JINJA_SNIPPET_DISABLE_CONSTRAINTS]
-            if args[1] == constants.OVERCLOUD_J2_EXCLUDES:
-                return ['', J2_EXCLUDES]
-            elif args[1] == constants.OVERCLOUD_J2_ROLES_NAME:
-                return ['', ROLE_DATA_DISABLE_CONSTRAINTS_YAML]
-            elif args[1] == constants.OVERCLOUD_J2_NETWORKS_NAME:
-                return ['', NETWORK_DATA_YAML]
-
-        def return_container_files(*args):
-            return ('headers', [
-                {'name': constants.OVERCLOUD_J2_NAME},
-                {'name': 'disable-constraints.role.j2.yaml'},
-                {'name': constants.OVERCLOUD_J2_ROLES_NAME},
-                {'name': constants.OVERCLOUD_J2_NETWORKS_NAME}])
-
-        mock_ctx = mock.MagicMock()
-        # setup swift
-        swift = mock.MagicMock()
-        swift.get_object = mock.MagicMock(side_effect=return_multiple_files)
-        swift.get_container = mock.MagicMock(
-            side_effect=return_container_files)
+    def _process_custom_roles_disable_constraints(
+            self, snippet, get_obj_client_mock):
+        swift = self._custom_roles_mock_objclient(
+            'disable-constraints.role.j2.yaml', snippet,
+            ROLE_DATA_DISABLE_CONSTRAINTS_YAML)
         get_obj_client_mock.return_value = swift
 
         # Test
         action = templates.ProcessTemplatesAction()
+        mock_ctx = mock.MagicMock()
         action._process_custom_roles(mock_ctx)
 
+        expected = EXPECTED_JINJA_RESULT.replace(
+            'CustomRole', 'RoleWithDisableConstraints')
+        put_object_mock_call = mock.call(
+            constants.DEFAULT_CONTAINER_NAME,
+            'overcloud.yaml',
+            expected)
+        self.assertEqual(swift.put_object.call_args_list[0],
+                         put_object_mock_call)
+
         put_object_mock_call = mock.call(
             constants.DEFAULT_CONTAINER_NAME,
             "rolewithdisableconstraints-disable-constraints.yaml",
             EXPECTED_JINJA_RESULT_DISABLE_CONSTRAINTS)
-        self.assertEqual(swift.put_object.call_args_list[1],
+        self.assertEqual(put_object_mock_call,
+                         swift.put_object.call_args_list[1])
+
+    def test_process_custom_roles_disable_constraints_old(self):
+        self._process_custom_roles_disable_constraints(
+            JINJA_SNIPPET_DISABLE_CONSTRAINTS_OLD)
+
+    def test_process_custom_roles_disable_constraints(self):
+        self._process_custom_roles_disable_constraints(
+            JINJA_SNIPPET_DISABLE_CONSTRAINTS)
+
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_custom_roles_networks(self, get_obj_client_mock):
+        swift = self._custom_roles_mock_objclient(
+            'role-networks.role.j2.yaml', JINJA_SNIPPET_ROLE_NETWORKS,
+            ROLE_DATA_ENABLE_NETWORKS)
+        get_obj_client_mock.return_value = swift
+
+        # Test
+        action = templates.ProcessTemplatesAction()
+        mock_ctx = mock.MagicMock()
+        action._process_custom_roles(mock_ctx)
+
+        expected = EXPECTED_JINJA_RESULT.replace(
+            'CustomRole', 'RoleWithNetworks')
+        put_object_mock_call = mock.call(
+            constants.DEFAULT_CONTAINER_NAME,
+            'overcloud.yaml',
+            expected)
+        self.assertEqual(swift.put_object.call_args_list[0],
                          put_object_mock_call)
 
+        put_object_mock_call = mock.call(
+            constants.DEFAULT_CONTAINER_NAME,
+            "rolewithnetworks-role-networks.yaml",
+            EXPECTED_JINJA_RESULT_ROLE_NETWORKS)
+        self.assertEqual(put_object_mock_call,
+                         swift.put_object.call_args_list[1])
+
     @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     def test_j2_render_and_put(self, get_obj_client_mock):
 
