@@ -27,6 +27,7 @@ from tripleo_common import constants
 
 
 _MIN_PASSWORD_SIZE = 25
+KEYSTONE_FERNET_REPO = '/etc/keystone/fernet-keys/'
 LOG = logging.getLogger(__name__)
 
 
@@ -68,6 +69,8 @@ def generate_passwords(mistralclient=None, stack_env=None):
         elif name in ('KeystoneCredential0', 'KeystoneCredential1',
                       'KeystoneFernetKey0', 'KeystoneFernetKey1'):
             passwords[name] = create_keystone_credential()
+        elif name == 'KeystoneFernetKeys':
+            passwords[name] = create_fernet_keys_repo_structure_and_keys()
         elif name == 'MigrationSshKey':
             passwords[name] = create_ssh_keypair()
         else:
@@ -76,6 +79,15 @@ def generate_passwords(mistralclient=None, stack_env=None):
     return passwords
 
 
+def create_fernet_keys_repo_structure_and_keys():
+    return {
+        KEYSTONE_FERNET_REPO + '0': {
+            'content': create_keystone_credential()},
+        KEYSTONE_FERNET_REPO + '1': {
+            'content': create_keystone_credential()}
+    }
+
+
 def create_cephx_key():
     # NOTE(gfidente): Taken from
     # https://github.com/ceph/ceph-deploy/blob/master/ceph_deploy/new.py#L21
